get_frame_depth

Function get_frame_depth 

pub fn get_frame_depth() -> usize
Determine depth of group nesting.

nesting created by {,},\bgroup,\egroup,\begingroup,\endgroup by counting all frames which are not Daemon frames (and thus don’t possess FRAME_LOCK). This may give incorrect results for some special environments (e.g. minipage)