lookup_digestable_definition

Function lookup_digestable_definition 

pub fn lookup_digestable_definition(token: &Token) -> Option<Stored>
Recognizes mathactive tokens in math mode and also looks for cs that have been let to other `executable’ tokens. Returns a definition object, or a “self inserting” token. Used for digestion.