UndoFrame

Struct UndoFrame 

pub struct UndoFrame { /* private fields */ }
For each of several tables (being “value”, “meaning”, “catcode” or other space of names), each table maintains the bound values, and “undo” defines the stack frames

Implementations

Source

impl UndoFrame

pub fn table(&self, name: TableName) -> &AssignmentCount

borrow the undo assignment counts for a given table name

pub fn table_mut(&mut self, name: TableName) -> &mut AssignmentCount

mutably borrow the undo assignment counts for a given table name