Table

Type Alias Table 

pub type Table = FxHashMap<SymStr, VecDeque<Stored>>;
The type of values that are storable by the different namespaced “tables” in State.

There are tables for:

catcode: keys are char; Also, math:char =1 when char is active in math. mathcode, sfcode, lccode, uccode, delcode : are similar to catcode but store additional kinds codes per char (see TeX) value: keys are anything (typically a string, though) and value is the value associated with it meaning: The definition assocated with key, usually a control-sequence. stash & stash_active: support named scopes (see also activateScope & deactivateScope)

Aliased Type

pub struct Table { /* private fields */ }