pub fn compute_indirect_model() -> IndirectModelExpand description
The indirect model includes all elements allowed as direct children, and all descendents of a node that can be inserted after autoOpen’ing intermediate elements.
This model therefor includes information from the Schema, as well as
auto_open information that may be introduced in binding files.