pub fn get_frame_depth() -> usizeExpand description
Determine depth of group nesting.
nesting created by {,},\bgroup,\egroup,\begingroup,\endgroup by counting all frames which are not Daemon frames (and thus don’t possess FRAME_LOCK). This may give incorrect results for some special environments (e.g. minipage)