pub fn lookup_definition(key: &Token) -> Result<Option<Rc<dyn Definition>>>Expand description
used for expansion & various queries Since we’re not doing digestion here, we don’t need to handle mathactive, nor cs let to executable tokens This returns a definition object, or undef