pub fn lookup_definition_stored(key: &Token) -> Result<Option<Stored>>Expand description
Returns a definition as Stored so that one can call .read_arguments
This can’t be specialized during compile-time over a trait object?
Instead we’ll dispatch via Stored at runtime, to allow generic calls.